How to start
============


Installation
#############


The ``pesfit`` package and its main dependencies can be installed in the following ways:


Install from git repository


.. code-block:: bash

	pip install git+https://github.com/mpes-kit/pesfit.git


Install and upgrade to the latest version from git repository, or override existing version


.. code-block:: bash

	pip install --upgrade git+https://github.com/mpes-kit/pesfit.git